@@ -1,128 +1,151 @@
 /*******************************************************************************
  *
- * Copyright (c) 2000-2003 Intel Corporation 
- * All rights reserved. 
- * Copyright (c) 2012 France Telecom All rights reserved. 
+ * Copyright (c) 2000-2003 Intel Corporation
+ * All rights reserved.
+ * Copyright (c) 2012 France Telecom All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions are met: 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * - Redistributions of source code must retain the above copyright notice, 
- * this list of conditions and the following disclaimer. 
- * - Redistributions in binary form must reproduce the above copyright notice, 
- * this list of conditions and the following disclaimer in the documentation 
- * and/or other materials provided with the distribution. 
- * - Neither name of Intel Corporation nor the names of its contributors 
- * may be used to endorse or promote products derived from this software 
+ * - Redistributions of source code must retain the above copyright notice,
+ * this list of conditions and the following disclaimer.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * - Neither name of Intel Corporation nor the names of its contributors
+ * may be used to endorse or promote products derived from this software
  * without specific prior written permission.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR 
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
- * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
  * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************/
 
-
 #include "config.h"
 
-
 /*!
  * \file
  */
 
-
 #if EXCLUDE_GENA == 0
-#ifdef INCLUDE_CLIENT_APIS
+	#ifdef INCLUDE_CLIENT_APIS
 
+		#include "UpnpEventSubscribe.h"
+		#include "client_table.h"
+		#include "gena.h"
+		#include "httpparser.h"
+		#include "httpreadwrite.h"
+		#include "parsetools.h"
+		#include "statcodes.h"
+		#include "upnpapi.h"
+		#include "uuid.h"
 
-#include "EventSubscribe.h"
-#include "gena.h"
-#include "httpparser.h"
-#include "httpreadwrite.h"
-#include "parsetools.h"
-#include "statcodes.h"
-#include "sysdep.h"
-#include "uuid.h"
-#include "upnpapi.h"
-
-#ifdef _WIN32
-	#define snprintf _snprintf
-#endif
+		#include "posix_overwrites.h" // IWYU pragma: keep
 
 extern ithread_mutex_t GlobalClientSubscribeMutex;
 
+typedef struct
+{
+	int handle;
+	int eventId;
+	void *Event;
+} job_arg;
+
+/*!
+ * \brief Free memory associated with job's argument
+ */
+static void free_subscribe_arg(void *arg)
+{
+	if (arg) {
+		job_arg *p = arg;
+		if (p->Event) {
+			UpnpEventSubscribe_delete(p->Event);
+		}
+		free(p);
+	}
+}
 
 /*!
  * \brief This is a thread function to send the renewal just before the
  * subscription times out.
  */
 static void GenaAutoRenewSubscription(
-	/*! [in] Thread data(upnp_timeout *) needed to send the renewal. */
+	/*! [in] Thread data(job_arg *) needed to send the renewal. */
 	void *input)
 {
-	upnp_timeout *event = (upnp_timeout *) input;
-	UpnpEventSubscribe *sub_struct = (UpnpEventSubscribe *)event->Event;
+	job_arg *arg = (job_arg *)input;
+	UpnpEventSubscribe *sub_struct = (UpnpEventSubscribe *)arg->Event;
 	void *cookie;
 	Upnp_FunPtr callback_fun;
 	struct Handle_Info *handle_info;
 	int send_callback = 0;
-	int eventType = 0;
+	Upnp_EventType eventType = 0;
 	int timeout = 0;
 	int errCode = 0;
 
 	if (AUTO_RENEW_TIME == 0) {
-		UpnpPrintf( UPNP_INFO, GENA, __FILE__, __LINE__, "GENA SUB EXPIRED");
+		UpnpPrintf(UPNP_INFO,
+			GENA,
+			__FILE__,
+			__LINE__,
+			"GENA SUB EXPIRED\n");
 		UpnpEventSubscribe_set_ErrCode(sub_struct, UPNP_E_SUCCESS);
 		send_callback = 1;
 		eventType = UPNP_EVENT_SUBSCRIPTION_EXPIRED;
 	} else {
-		UpnpPrintf(UPNP_INFO, GENA, __FILE__, __LINE__, "GENA AUTO RENEW");
+		UpnpPrintf(UPNP_INFO,
+			GENA,
+			__FILE__,
+			__LINE__,
+			"GENA AUTO RENEW\n");
 		timeout = UpnpEventSubscribe_get_TimeOut(sub_struct);
-		errCode = genaRenewSubscription(
-			event->handle,
+		errCode = genaRenewSubscription(arg->handle,
 			UpnpEventSubscribe_get_SID(sub_struct),
 			&timeout);
 		UpnpEventSubscribe_set_ErrCode(sub_struct, errCode);
 		UpnpEventSubscribe_set_TimeOut(sub_struct, timeout);
-		if (errCode != UPNP_E_SUCCESS &&
-		    errCode != GENA_E_BAD_SID &&
-		    errCode != GENA_E_BAD_HANDLE) {
+		if (errCode != UPNP_E_SUCCESS && errCode != GENA_E_BAD_SID &&
+			errCode != GENA_E_BAD_HANDLE) {
 			send_callback = 1;
 			eventType = UPNP_EVENT_AUTORENEWAL_FAILED;
 		}
 	}
 
 	if (send_callback) {
-		HandleReadLock();
-		if( GetHandleInfo( event->handle, &handle_info ) != HND_CLIENT ) {
-			HandleUnlock();
-			free_upnp_timeout(event);
+		HandleReadLock(__FILE__, __LINE__);
+		if (GetHandleInfo(arg->handle, &handle_info) != HND_CLIENT) {
+			HandleUnlock(__FILE__, __LINE__);
+			free_subscribe_arg(arg);
 			goto end_function;
 		}
-		UpnpPrintf(UPNP_INFO, GENA, __FILE__, __LINE__, "HANDLE IS VALID");
+		UpnpPrintf(UPNP_INFO,
+			GENA,
+			__FILE__,
+			__LINE__,
+			"HANDLE IS VALID\n");
 
 		/* make callback */
 		callback_fun = handle_info->Callback;
 		cookie = handle_info->Cookie;
-		HandleUnlock();
-		callback_fun(eventType, event->Event, cookie);
+		HandleUnlock(__FILE__, __LINE__);
+		callback_fun(eventType, arg->Event, cookie);
 	}
 
-	free_upnp_timeout(event);
+	free_subscribe_arg(arg);
 
 end_function:
 	return;
 }
 
-
 /*!
  * \brief Schedules a job to renew the subscription just before time out.
  *
@@ -137,8 +160,8 @@ static int ScheduleGenaAutoRenew(
 	/*! [in] Subscription being renewed. */
 	GenlibClientSubscription *sub)
 {
-	UpnpEventSubscribe *RenewEventStruct = NULL;
-	upnp_timeout *RenewEvent = NULL;
+	UpnpEventSubscribe *RenewEvent = NULL;
+	job_arg *arg = NULL;
 	int return_code = GENA_SUCCESS;
 	ThreadPoolJob job;
 
@@ -149,48 +172,48 @@ static int ScheduleGenaAutoRenew(
 		goto end_function;
 	}
 
-	RenewEventStruct = UpnpEventSubscribe_new();
-	if (RenewEventStruct == NULL) {
+	RenewEvent = UpnpEventSubscribe_new();
+	if (RenewEvent == NULL) {
 		return_code = UPNP_E_OUTOF_MEMORY;
 		goto end_function;
 	}
 
-	RenewEvent = (upnp_timeout *) malloc(sizeof(upnp_timeout));
-	if (RenewEvent == NULL) {
-		free(RenewEventStruct);
+	arg = (job_arg *)malloc(sizeof(job_arg));
+	if (arg == NULL) {
+		free(RenewEvent);
 		return_code = UPNP_E_OUTOF_MEMORY;
 		goto end_function;
 	}
-	memset(RenewEvent, 0, sizeof(upnp_timeout));
+	memset(arg, 0, sizeof(job_arg));
 
 	/* schedule expire event */
-	UpnpEventSubscribe_set_ErrCode(RenewEventStruct, UPNP_E_SUCCESS);
-	UpnpEventSubscribe_set_TimeOut(RenewEventStruct, TimeOut);
-	UpnpEventSubscribe_set_SID(RenewEventStruct, GenlibClientSubscription_get_SID(sub));
-	UpnpEventSubscribe_set_PublisherUrl(RenewEventStruct, GenlibClientSubscription_get_EventURL(sub));
+	UpnpEventSubscribe_set_ErrCode(RenewEvent, UPNP_E_SUCCESS);
+	UpnpEventSubscribe_set_TimeOut(RenewEvent, TimeOut);
+	UpnpEventSubscribe_set_SID(
+		RenewEvent, GenlibClientSubscription_get_SID(sub));
+	UpnpEventSubscribe_set_PublisherUrl(
+		RenewEvent, GenlibClientSubscription_get_EventURL(sub));
 
-	/* RenewEvent->EventType=UPNP_EVENT_SUBSCRIPTION_EXPIRE; */
-	RenewEvent->handle = client_handle;
-	RenewEvent->Event = RenewEventStruct;
+	arg->handle = client_handle;
+	arg->Event = RenewEvent;
 
-	TPJobInit(&job, (start_routine) GenaAutoRenewSubscription, RenewEvent);
-	TPJobSetFreeFunction(&job, (free_routine)free_upnp_timeout);
+	TPJobInit(&job, (start_routine)GenaAutoRenewSubscription, arg);
+	TPJobSetFreeFunction(&job, (free_routine)free_subscribe_arg);
 	TPJobSetPriority(&job, MED_PRIORITY);
 
 	/* Schedule the job */
-	return_code = TimerThreadSchedule(
-		&gTimerThread,
+	return_code = TimerThreadSchedule(&gTimerThread,
 		TimeOut - AUTO_RENEW_TIME,
 		REL_SEC,
-		&job, SHORT_TERM,
-		&(RenewEvent->eventId));
+		&job,
+		SHORT_TERM,
+		&(arg->eventId));
 	if (return_code != UPNP_E_SUCCESS) {
-		free(RenewEvent);
-		free(RenewEventStruct);
+		free_subscribe_arg(arg);
 		goto end_function;
 	}
 
-	GenlibClientSubscription_set_RenewEventId(sub, RenewEvent->eventId);
+	GenlibClientSubscription_set_RenewEventId(sub, arg->eventId);
 
 	return_code = GENA_SUCCESS;
 
@@ -199,7 +222,6 @@ end_function:
 	return return_code;
 }
 
-
 /*!
  * \brief Sends the UNSUBCRIBE gena request and recieves the response from the
  * 	device and returns it as a parameter.
@@ -212,15 +234,14 @@ static int gena_unsubscribe(
 	/*! [in] The subcription ID. */
 	const UpnpString *sid,
 	/*! [out] The UNSUBCRIBE response from the device. */
-	http_parser_t *response )
+	http_parser_t *response)
 {
 	int return_code;
 	uri_type dest_url;
 	membuffer request;
 
 	/* parse url */
-	return_code = http_FixStrUrl(
-		UpnpString_get_String(url),
+	return_code = http_FixStrUrl(UpnpString_get_String(url),
 		UpnpString_get_Length(url),
 		&dest_url);
 	if (return_code != 0) {
@@ -230,11 +251,16 @@ static int gena_unsubscribe(
 	/* make request msg */
 	membuffer_init(&request);
 	request.size_inc = 30;
-	return_code = http_MakeMessage(
-		&request, 1, 1,
-		"q" "ssc" "Uc",
-		HTTPMETHOD_UNSUBSCRIBE, &dest_url,
-		"SID: ", UpnpString_get_String(sid));
+	return_code = http_MakeMessage(&request,
+		1,
+		1,
+		"q"
+		"ssc"
+		"Uc",
+		HTTPMETHOD_UNSUBSCRIBE,
+		&dest_url,
+		"SID: ",
+		UpnpString_get_String(sid));
 
 	/* Not able to make the message so destroy the existing buffer */
 	if (return_code != 0) {
@@ -244,9 +270,12 @@ static int gena_unsubscribe(
 	}
 
 	/* send request and get reply */
-	return_code = http_RequestAndResponse(
-		&dest_url, request.buf, request.length,
-		HTTPMETHOD_UNSUBSCRIBE, HTTP_DEFAULT_TIMEOUT, response);
+	return_code = http_RequestAndResponse(&dest_url,
+		request.buf,
+		request.length,
+		HTTPMETHOD_UNSUBSCRIBE,
+		HTTP_DEFAULT_TIMEOUT,
+		response);
 	membuffer_destroy(&request);
 	if (return_code != 0) {
 		httpmsg_destroy(&response->msg);
@@ -260,7 +289,6 @@ static int gena_unsubscribe(
 	return return_code;
 }
 
-
 /*!
  * \brief Subscribes or renew subscription.
  *
@@ -278,7 +306,7 @@ static int gena_subscribe(
 	UpnpString *sid)
 {
 	int return_code;
-	int parse_ret = 0;
+	parse_status_t parse_ret = 0;
 	int local_timeout = CP_MINIMUM_SUBSCRIPTION_TIME;
 	memptr sid_hdr;
 	memptr timeout_hdr;
@@ -297,18 +325,19 @@ static int gena_subscribe(
 	if (*timeout < 0) {
 		memset(timeout_str, 0, sizeof(timeout_str));
 		strncpy(timeout_str, "infinite", sizeof(timeout_str) - 1);
-	} else if(*timeout < CP_MINIMUM_SUBSCRIPTION_TIME) {
-		rc = snprintf(timeout_str, sizeof(timeout_str),
-			"%d", CP_MINIMUM_SUBSCRIPTION_TIME);
+	} else if (*timeout < CP_MINIMUM_SUBSCRIPTION_TIME) {
+		rc = snprintf(timeout_str,
+			sizeof(timeout_str),
+			"%d",
+			CP_MINIMUM_SUBSCRIPTION_TIME);
 	} else {
 		rc = snprintf(timeout_str, sizeof(timeout_str), "%d", *timeout);
 	}
-	if (rc < 0 || (unsigned int) rc >= sizeof(timeout_str))
+	if (rc < 0 || (unsigned int)rc >= sizeof(timeout_str))
 		return UPNP_E_OUTOF_MEMORY;
 
 	/* parse url */
-	return_code = http_FixStrUrl(
-		UpnpString_get_String(url),
+	return_code = http_FixStrUrl(UpnpString_get_String(url),
 		UpnpString_get_Length(url),
 		&dest_url);
 	if (return_code != 0) {
@@ -320,34 +349,65 @@ static int gena_subscribe(
 	request.size_inc = 30;
 	if (renewal_sid) {
 		/* renew subscription */
-		return_code = http_MakeMessage(
-			&request, 1, 1,
-			"q" "ssc" "sscc",
-			HTTPMETHOD_SUBSCRIBE, &dest_url,
-			"SID: ", UpnpString_get_String(renewal_sid),
-			"TIMEOUT: Second-", timeout_str );
+		return_code = http_MakeMessage(&request,
+			1,
+			1,
+			"q"
+			"ssc"
+			"sscc",
+			HTTPMETHOD_SUBSCRIBE,
+			&dest_url,
+			"SID: ",
+			UpnpString_get_String(renewal_sid),
+			"TIMEOUT: Second-",
+			timeout_str);
 	} else {
 		/* subscribe */
 		if (dest_url.hostport.IPaddress.ss_family == AF_INET6) {
-			struct sockaddr_in6* DestAddr6 = (struct sockaddr_in6*)&dest_url.hostport.IPaddress;
-			return_code = http_MakeMessage(
-				&request, 1, 1,
-				"q" "sssdsc" "sc" "sscc",
-				HTTPMETHOD_SUBSCRIBE, &dest_url,
+			struct sockaddr_in6 *DestAddr6 =
+				(struct sockaddr_in6 *)&dest_url.hostport
+					.IPaddress;
+			return_code = http_MakeMessage(&request,
+				1,
+				1,
+				"q"
+				"sssdsc"
+				"sc"
+				"sscc",
+				HTTPMETHOD_SUBSCRIBE,
+				&dest_url,
 				"CALLBACK: <http://[",
-				(IN6_IS_ADDR_LINKLOCAL(&DestAddr6->sin6_addr) || strlen(gIF_IPV6_ULA_GUA) == 0) ?
-					gIF_IPV6 : gIF_IPV6_ULA_GUA,
-				"]:", LOCAL_PORT_V6, "/>",
+				(IN6_IS_ADDR_LINKLOCAL(&DestAddr6->sin6_addr) ||
+					strlen(gIF_IPV6_ULA_GUA) == 0)
+					? gIF_IPV6
+					: gIF_IPV6_ULA_GUA,
+				"]:",
+				(IN6_IS_ADDR_LINKLOCAL(&DestAddr6->sin6_addr) ||
+					strlen(gIF_IPV6_ULA_GUA) == 0)
+					? LOCAL_PORT_V6
+					: LOCAL_PORT_V6_ULA_GUA,
+				"/>",
 				"NT: upnp:event",
-				"TIMEOUT: Second-", timeout_str);
+				"TIMEOUT: Second-",
+				timeout_str);
 		} else {
-			return_code = http_MakeMessage(
-				&request, 1, 1,
-				"q" "sssdsc" "sc" "sscc",
-				HTTPMETHOD_SUBSCRIBE, &dest_url,
-				"CALLBACK: <http://", gIF_IPV4, ":", LOCAL_PORT_V4, "/>",
+			return_code = http_MakeMessage(&request,
+				1,
+				1,
+				"q"
+				"sssdsc"
+				"sc"
+				"sscc",
+				HTTPMETHOD_SUBSCRIBE,
+				&dest_url,
+				"CALLBACK: <http://",
+				gIF_IPV4,
+				":",
+				LOCAL_PORT_V4,
+				"/>",
 				"NT: upnp:event",
-				"TIMEOUT: Second-", timeout_str);
+				"TIMEOUT: Second-",
+				timeout_str);
 		}
 	}
 	if (return_code != 0) {
@@ -355,7 +415,8 @@ static int gena_subscribe(
 	}
 
 	/* send request and get reply */
-	return_code = http_RequestAndResponse(&dest_url, request.buf,
+	return_code = http_RequestAndResponse(&dest_url,
+		request.buf,
 		request.length,
 		HTTPMETHOD_SUBSCRIBE,
 		HTTP_DEFAULT_TIMEOUT,
@@ -375,22 +436,24 @@ static int gena_subscribe(
 
 	/* get SID and TIMEOUT */
 	if (httpmsg_find_hdr(&response.msg, HDR_SID, &sid_hdr) == NULL ||
-	    sid_hdr.length == 0 ||
-	    httpmsg_find_hdr( &response.msg, HDR_TIMEOUT, &timeout_hdr ) == NULL ||
-	    timeout_hdr.length == 0 ) {
-		httpmsg_destroy( &response.msg );
+		sid_hdr.length == 0 ||
+		httpmsg_find_hdr(&response.msg, HDR_TIMEOUT, &timeout_hdr) ==
+			NULL ||
+		timeout_hdr.length == 0) {
+		httpmsg_destroy(&response.msg);
 
 		return UPNP_E_BAD_RESPONSE;
 	}
 
 	/* save timeout */
-	parse_ret = matchstr(timeout_hdr.buf, timeout_hdr.length, "%iSecond-%d%0", timeout);
+	parse_ret = matchstr(
+		timeout_hdr.buf, timeout_hdr.length, "%iSecond-%d%0", timeout);
 	if (parse_ret == PARSE_OK) {
 		/* nothing to do */
 	} else if (memptr_cmp_nocase(&timeout_hdr, "Second-infinite") == 0) {
 		*timeout = -1;
 	} else {
-		httpmsg_destroy( &response.msg );
+		httpmsg_destroy(&response.msg);
 
 		return UPNP_E_BAD_RESPONSE;
 	}
@@ -407,7 +470,6 @@ static int gena_subscribe(
 	return UPNP_E_SUCCESS;
 }
 
-
 int genaUnregisterClient(UpnpClient_Handle client_handle)
 {
 	GenlibClientSubscription *sub_copy = GenlibClientSubscription_new();
@@ -416,10 +478,10 @@ int genaUnregisterClient(UpnpClient_Handle client_handle)
 	http_parser_t response;
 
 	while (1) {
-		HandleLock();
+		HandleLock(__FILE__, __LINE__);
 
 		if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-			HandleUnlock();
+			HandleUnlock(__FILE__, __LINE__);
 			return_code = GENA_E_BAD_HANDLE;
 			goto exit_function;
 		}
@@ -427,12 +489,12 @@ int genaUnregisterClient(UpnpClient_Handle client_handle)
 			return_code = UPNP_E_SUCCESS;
 			break;
 		}
-		GenlibClientSubscription_assign(sub_copy, handle_info->ClientSubList);
-		RemoveClientSubClientSID(
-			&handle_info->ClientSubList,
+		GenlibClientSubscription_assign(
+			sub_copy, handle_info->ClientSubList);
+		RemoveClientSubClientSID(&handle_info->ClientSubList,
 			GenlibClientSubscription_get_SID(sub_copy));
 
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 
 		return_code = gena_unsubscribe(
 			GenlibClientSubscription_get_EventURL(sub_copy),
@@ -445,18 +507,15 @@ int genaUnregisterClient(UpnpClient_Handle client_handle)
 	}
 
 	freeClientSubList(handle_info->ClientSubList);
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 exit_function:
 	GenlibClientSubscription_delete(sub_copy);
 	return return_code;
 }
 
-
-#ifdef INCLUDE_CLIENT_APIS
-int genaUnSubscribe(
-	UpnpClient_Handle client_handle,
-	const UpnpString *in_sid)
+		#ifdef INCLUDE_CLIENT_APIS
+int genaUnSubscribe(UpnpClient_Handle client_handle, const UpnpString *in_sid)
 {
 	GenlibClientSubscription *sub = NULL;
 	int return_code = GENA_SUCCESS;
@@ -465,20 +524,20 @@ int genaUnSubscribe(
 	http_parser_t response;
 
 	/* validate handle and sid */
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return_code = GENA_E_BAD_HANDLE;
 		goto exit_function;
 	}
 	sub = GetClientSubClientSID(handle_info->ClientSubList, in_sid);
 	if (sub == NULL) {
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return_code = GENA_E_BAD_SID;
 		goto exit_function;
 	}
 	GenlibClientSubscription_assign(sub_copy, sub);
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	return_code = gena_unsubscribe(
 		GenlibClientSubscription_get_EventURL(sub_copy),
@@ -489,31 +548,30 @@ int genaUnSubscribe(
 	}
 	free_client_subscription(sub_copy);
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return_code = GENA_E_BAD_HANDLE;
 		goto exit_function;
 	}
 	RemoveClientSubClientSID(&handle_info->ClientSubList, in_sid);
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 exit_function:
 	GenlibClientSubscription_delete(sub_copy);
 	return return_code;
 }
-#endif /* INCLUDE_CLIENT_APIS */
+		#endif /* INCLUDE_CLIENT_APIS */
 
-
-#ifdef INCLUDE_CLIENT_APIS
-int genaSubscribe(
-	UpnpClient_Handle client_handle,
+		#ifdef INCLUDE_CLIENT_APIS
+int genaSubscribe(UpnpClient_Handle client_handle,
 	const UpnpString *PublisherURL,
 	int *TimeOut,
 	UpnpString *out_sid)
 {
 	int return_code = GENA_SUCCESS;
-	GenlibClientSubscription *newSubscription = GenlibClientSubscription_new();
+	GenlibClientSubscription *newSubscription =
+		GenlibClientSubscription_new();
 	uuid_upnp uid;
 	Upnp_SID temp_sid;
 	Upnp_SID temp_sid2;
@@ -525,40 +583,45 @@ int genaSubscribe(
 	memset(temp_sid, 0, sizeof(temp_sid));
 	memset(temp_sid2, 0, sizeof(temp_sid2));
 
-	UpnpPrintf(UPNP_INFO, GENA, __FILE__, __LINE__, "GENA SUBSCRIBE BEGIN");
+	UpnpPrintf(
+		UPNP_INFO, GENA, __FILE__, __LINE__, "GENA SUBSCRIBE BEGIN\n");
 
 	UpnpString_clear(out_sid);
 
-	HandleReadLock();
+	HandleReadLock(__FILE__, __LINE__);
 	/* validate handle */
 	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
 		return_code = GENA_E_BAD_HANDLE;
 		SubscribeLock();
 		goto error_handler;
 	}
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	/* subscribe */
 	SubscribeLock();
 	return_code = gena_subscribe(PublisherURL, TimeOut, NULL, ActualSID);
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 	if (return_code != UPNP_E_SUCCESS) {
-		UpnpPrintf( UPNP_CRITICAL, GENA, __FILE__, __LINE__,
-			"SUBSCRIBE FAILED in transfer error code: %d returned\n",
-			return_code );
+		UpnpPrintf(UPNP_CRITICAL,
+			GENA,
+			__FILE__,
+			__LINE__,
+			"SUBSCRIBE FAILED in transfer error code: %d "
+			"returned\n",
+			return_code);
 		goto error_handler;
 	}
 
-	if(GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
+	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
 		return_code = GENA_E_BAD_HANDLE;
 		goto error_handler;
 	}
 
 	/* generate client SID */
-	uuid_create(&uid );
+	uuid_create(&uid);
 	upnp_uuid_unpack(&uid, temp_sid);
 	rc = snprintf(temp_sid2, sizeof(temp_sid2), "uuid:%s", temp_sid);
-	if (rc < 0 || (unsigned int) rc >= sizeof(temp_sid2)) {
+	if (rc < 0 || (unsigned int)rc >= sizeof(temp_sid2)) {
 		return_code = UPNP_E_OUTOF_MEMORY;
 		goto error_handler;
 	}
@@ -576,29 +639,28 @@ int genaSubscribe(
 	GenlibClientSubscription_set_SID(newSubscription, out_sid);
 	GenlibClientSubscription_set_ActualSID(newSubscription, ActualSID);
 	GenlibClientSubscription_set_EventURL(newSubscription, EventURL);
-	GenlibClientSubscription_set_Next(newSubscription, handle_info->ClientSubList);
+	GenlibClientSubscription_set_Next(
+		newSubscription, handle_info->ClientSubList);
 	handle_info->ClientSubList = newSubscription;
 
 	/* schedule expiration event */
-	return_code = ScheduleGenaAutoRenew(client_handle, *TimeOut, newSubscription);
+	return_code =
+		ScheduleGenaAutoRenew(client_handle, *TimeOut, newSubscription);
 
 error_handler:
 	UpnpString_delete(ActualSID);
 	UpnpString_delete(EventURL);
 	if (return_code != UPNP_E_SUCCESS)
 		GenlibClientSubscription_delete(newSubscription);
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 	SubscribeUnlock();
 
 	return return_code;
 }
-#endif /* INCLUDE_CLIENT_APIS */
-
+		#endif /* INCLUDE_CLIENT_APIS */
 
 int genaRenewSubscription(
-	UpnpClient_Handle client_handle,
-	const UpnpString *in_sid,
-	int *TimeOut)
+	UpnpClient_Handle client_handle, const UpnpString *in_sid, int *TimeOut)
 {
 	int return_code = GENA_SUCCESS;
 	GenlibClientSubscription *sub = NULL;
@@ -607,11 +669,11 @@ int genaRenewSubscription(
 	UpnpString *ActualSID = UpnpString_new();
 	ThreadPoolJob tempJob;
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	/* validate handle and sid */
 	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 
 		return_code = GENA_E_BAD_HANDLE;
 		goto exit_function;
@@ -619,37 +681,40 @@ int genaRenewSubscription(
 
 	sub = GetClientSubClientSID(handle_info->ClientSubList, in_sid);
 	if (sub == NULL) {
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 
 		return_code = GENA_E_BAD_SID;
 		goto exit_function;
 	}
 
 	/* remove old events */
-	if (TimerThreadRemove(
-		&gTimerThread,
-		GenlibClientSubscription_get_RenewEventId(sub),
-		&tempJob) == 0 ) {
-		free_upnp_timeout((upnp_timeout *)tempJob.arg);
+	if (TimerThreadRemove(&gTimerThread,
+		    GenlibClientSubscription_get_RenewEventId(sub),
+		    &tempJob) == 0) {
+		tempJob.free_func(tempJob.arg);
 	}
 
-	UpnpPrintf(UPNP_INFO, GENA, __FILE__, __LINE__, "REMOVED AUTO RENEW  EVENT");
+	UpnpPrintf(UPNP_INFO,
+		GENA,
+		__FILE__,
+		__LINE__,
+		"REMOVED AUTO RENEW  EVENT\n");
 
 	GenlibClientSubscription_set_RenewEventId(sub, -1);
 	GenlibClientSubscription_assign(sub_copy, sub);
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
-	return_code = gena_subscribe(
-		GenlibClientSubscription_get_EventURL(sub_copy),
-		TimeOut,
-		GenlibClientSubscription_get_ActualSID(sub_copy),
-		ActualSID);
+	return_code =
+		gena_subscribe(GenlibClientSubscription_get_EventURL(sub_copy),
+			TimeOut,
+			GenlibClientSubscription_get_ActualSID(sub_copy),
+			ActualSID);
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return_code = GENA_E_BAD_HANDLE;
 		goto exit_function;
 	}
@@ -660,7 +725,7 @@ int genaRenewSubscription(
 		/* network failure (remove client sub) */
 		RemoveClientSubClientSID(&handle_info->ClientSubList, in_sid);
 		free_client_subscription(sub_copy);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 
@@ -668,7 +733,7 @@ int genaRenewSubscription(
 	sub = GetClientSubClientSID(handle_info->ClientSubList, in_sid);
 	if (sub == NULL) {
 		free_client_subscription(sub_copy);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return_code = GENA_E_BAD_SID;
 		goto exit_function;
 	}
@@ -679,12 +744,11 @@ int genaRenewSubscription(
 	/* start renew subscription timer */
 	return_code = ScheduleGenaAutoRenew(client_handle, *TimeOut, sub);
 	if (return_code != GENA_SUCCESS) {
-		RemoveClientSubClientSID(
-			&handle_info->ClientSubList,
+		RemoveClientSubClientSID(&handle_info->ClientSubList,
 			GenlibClientSubscription_get_SID(sub));
 	}
 	free_client_subscription(sub_copy);
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 exit_function:
 	UpnpString_delete(ActualSID);
@@ -692,10 +756,7 @@ exit_function:
 	return return_code;
 }
 
-
-void gena_process_notification_event(
-	SOCKINFO *info,
-	http_message_t *event)
+void gena_process_notification_event(SOCKINFO *info, http_message_t *event)
 {
 	UpnpEvent *event_struct = UpnpEvent_new();
 	IXML_Document *ChangedVars = NULL;
@@ -710,8 +771,7 @@ void gena_process_notification_event(
 	int err_ret = HTTP_PRECONDITION_FAILED;
 
 	memptr sid_hdr;
-	memptr nt_hdr,
-	nts_hdr;
+	memptr nt_hdr, nts_hdr;
 	memptr seq_hdr;
 
 	/* get SID */
@@ -724,119 +784,128 @@ void gena_process_notification_event(
 
 	/* get event key */
 	if (httpmsg_find_hdr(event, HDR_SEQ, &seq_hdr) == NULL ||
-	    matchstr(seq_hdr.buf, seq_hdr.length, "%d%0", &eventKey) != PARSE_OK) {
-		error_respond( info, HTTP_BAD_REQUEST, event );
+		matchstr(seq_hdr.buf, seq_hdr.length, "%d%0", &eventKey) !=
+			PARSE_OK) {
+		error_respond(info, HTTP_BAD_REQUEST, event);
 		goto exit_function;
 	}
 
 	/* get NT and NTS headers */
 	if (httpmsg_find_hdr(event, HDR_NT, &nt_hdr) == NULL ||
-	    httpmsg_find_hdr(event, HDR_NTS, &nts_hdr) == NULL) {
-		error_respond( info, HTTP_BAD_REQUEST, event );
+		httpmsg_find_hdr(event, HDR_NTS, &nts_hdr) == NULL) {
+		error_respond(info, HTTP_BAD_REQUEST, event);
 		goto exit_function;
 	}
 
 	/* verify NT and NTS headers */
 	if (memptr_cmp(&nt_hdr, "upnp:event") != 0 ||
-	    memptr_cmp(&nts_hdr, "upnp:propchange") != 0) {
+		memptr_cmp(&nts_hdr, "upnp:propchange") != 0) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, event);
 		goto exit_function;
 	}
 
 	/* parse the content (should be XML) */
-	if (!has_xml_content_type(event) ||
-	    event->msg.length == 0 ||
-	    ixmlParseBufferEx(event->entity.buf, &ChangedVars) != IXML_SUCCESS) {
+	if (!has_xml_content_type(event) || event->msg.length == 0 ||
+		ixmlParseBufferEx(event->entity.buf, &ChangedVars) !=
+			IXML_SUCCESS) {
 		error_respond(info, HTTP_BAD_REQUEST, event);
 		goto exit_function;
 	}
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	/* get client info */
-	if (GetClientHandleInfo(&client_handle_start, &handle_info) != HND_CLIENT) {
+	if (GetClientHandleInfo(&client_handle_start, &handle_info) !=
+		HND_CLIENT) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, event);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
-	for (client_handle = client_handle_start; client_handle < NUM_HANDLE; client_handle++) {
-	HandleLock();
+	for (client_handle = client_handle_start; client_handle < NUM_HANDLE;
+		client_handle++) {
+		HandleLock(__FILE__, __LINE__);
 
-	/* get client info */
-	if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-		HandleUnlock();
-		continue;
-	}
-
-	/* get subscription based on SID */
-	subscription = GetClientSubActualSID(handle_info->ClientSubList, &sid);
-	if (subscription == NULL) {
-		if (eventKey == 0) {
-			/* wait until we've finished processing a subscription  */
-			/*   (if we are in the middle) */
-			/* this is to avoid mistakenly rejecting the first event if we  */
-			/*   receive it before the subscription response */
-			HandleUnlock();
-
-			/* try and get Subscription Lock  */
-			/*   (in case we are in the process of subscribing) */
-			SubscribeLock();
-
-			/* get HandleLock again */
-			HandleLock();
-
-			if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
-				SubscribeUnlock();
-				HandleUnlock();
-				continue;
-			}
-
-			subscription = GetClientSubActualSID(handle_info->ClientSubList, &sid);
-			if (subscription == NULL) {
-				SubscribeUnlock();
-				HandleUnlock();
-				continue;
-			}
-
-			SubscribeUnlock();
-		} else {
-			HandleUnlock();
+		/* get client info */
+		if (GetHandleInfo(client_handle, &handle_info) != HND_CLIENT) {
+			HandleUnlock(__FILE__, __LINE__);
 			continue;
 		}
+
+		/* get subscription based on SID */
+		subscription =
+			GetClientSubActualSID(handle_info->ClientSubList, &sid);
+		if (subscription == NULL) {
+			if (eventKey == 0) {
+				/* wait until we've finished processing a
+				 * subscription  */
+				/*   (if we are in the middle) */
+				/* this is to avoid mistakenly rejecting the
+				 * first event if we  */
+				/*   receive it before the subscription response
+				 */
+				HandleUnlock(__FILE__, __LINE__);
+
+				/* try and get Subscription Lock  */
+				/*   (in case we are in the process of
+				 * subscribing) */
+				SubscribeLock();
+
+				/* get HandleLock again */
+				HandleLock(__FILE__, __LINE__);
+
+				if (GetHandleInfo(client_handle,
+					    &handle_info) != HND_CLIENT) {
+					SubscribeUnlock();
+					HandleUnlock(__FILE__, __LINE__);
+					continue;
+				}
+
+				subscription = GetClientSubActualSID(
+					handle_info->ClientSubList, &sid);
+				if (subscription == NULL) {
+					SubscribeUnlock();
+					HandleUnlock(__FILE__, __LINE__);
+					continue;
+				}
+
+				SubscribeUnlock();
+			} else {
+				HandleUnlock(__FILE__, __LINE__);
+				continue;
+			}
+		}
+
+		/* success */
+		err_ret = HTTP_OK;
+
+		/* fill event struct */
+		UpnpEvent_set_EventKey(event_struct, eventKey);
+		UpnpEvent_set_ChangedVariables(event_struct, ChangedVars);
+		UpnpEvent_set_SID(event_struct,
+			GenlibClientSubscription_get_SID(subscription));
+
+		/* copy callback */
+		callback = handle_info->Callback;
+		cookie = handle_info->Cookie;
+
+		HandleUnlock(__FILE__, __LINE__);
+
+		/* make callback with event struct */
+		/* In future, should find a way of mainting */
+		/* that the handle is not unregistered in the middle of a */
+		/* callback */
+		callback(UPNP_EVENT_RECEIVED, event_struct, cookie);
 	}
 
-	/* success */
-	err_ret = HTTP_OK;
-
-	/* fill event struct */
-	UpnpEvent_set_EventKey(event_struct, eventKey);
-	UpnpEvent_set_ChangedVariables(event_struct, ChangedVars);
-	UpnpEvent_set_SID(event_struct, GenlibClientSubscription_get_SID(subscription));
-
-	/* copy callback */
-	callback = handle_info->Callback;
-	cookie = handle_info->Cookie;
-
-	HandleUnlock();
-
-	/* make callback with event struct */
-	/* In future, should find a way of mainting */
-	/* that the handle is not unregistered in the middle of a */
-	/* callback */
-	callback(UPNP_EVENT_RECEIVED, event_struct, cookie);
-	}
-
-	error_respond( info, err_ret, event );
+	error_respond(info, err_ret, event);
 
 exit_function:
 	ixmlDocument_free(ChangedVars);
 	UpnpEvent_delete(event_struct);
 }
 
-
-#endif /* INCLUDE_CLIENT_APIS */
-#endif /* EXCLUDE_GENA */
-
+	#endif /* INCLUDE_CLIENT_APIS */
+#endif	       /* EXCLUDE_GENA */
